@@ -1,35 +1,29 @@
-# partial unit test for gmpy extra cover
+# partial unit test for gmpy2 extra cover
 # relies on Tim Peters' "doctest.py" test-driver
-
 r'''
->>> _g.gmp_version()[:3] in ('5.0', '4.3', '')
-True
->>> _g.mpir_version()[:3] in ( '2.3', '2.4', '2.5', '')
-True
 >>> _g.version()
-'1.15'
->>> int('gmpy.c' in _g._cvsid())
+'2.0.8'
+>>> int('gmpy2.c' in _g._cvsid())
 1
 '''
 
-import gmpy as _g, doctest, sys
+import gmpy2 as _g, doctest, sys
 __test__={}
-r = _g.rand
 
 __test__['misc_stuff']=\
 r'''
->>> junk=_g.set_debug(0)
->>> knuj=_g.set_debug(junk)
->>> junk==_g.set_debug(junk)
-1
->>> _g.set_fcoform(None)
->>> _g.set_fcoform()
->>> print(_g.mpf(3.0))
+>>> print(_g.mpfr(3.0))
 3.0
->>> _g.gmp_limbsize() in (32, 64)
+>>> _g.mp_limbsize() in (32, 64)
 True
+>>> _g.next_prime(2357*7069-1) == 2357*7069
+False
 '''
 
+# If the next_prime() test fails, you have encountered a bug in MPIR. Please
+# see https://code.google.com/p/gmpy/issues/detail?id=76 for more details.
+
+
 try:
     x = float('inf')
 except ValueError:
@@ -39,42 +33,32 @@ else:
 r'''
 >>> x = float('inf')
 >>> n = float('nan')
->>> _g.mpf(x)
-Traceback (most recent call last):
-  ...
-ValueError: gmpy does not handle infinity
->>> _g.mpf(-x)
-Traceback (most recent call last):
-  ...
-ValueError: gmpy does not handle infinity
+>>> _g.mpfr(x)
+mpfr('inf')
+>>> _g.mpfr(-x)
+mpfr('-inf')
 >>> _g.mpq(x)
 Traceback (most recent call last):
   ...
-ValueError: gmpy does not handle infinity
+OverflowError: 'mpq' does not support Infinity
 >>> _g.mpq(-x)
 Traceback (most recent call last):
   ...
-ValueError: gmpy does not handle infinity
+OverflowError: 'mpq' does not support Infinity
 >>> _g.mpz(x)
 Traceback (most recent call last):
   ...
-ValueError: gmpy does not handle infinity
+OverflowError: 'mpz' does not support Infinity
 >>> _g.mpz(-x)
 Traceback (most recent call last):
   ...
-ValueError: gmpy does not handle infinity
->>> _g.mpf(n)
-Traceback (most recent call last):
-  ...
-ValueError: gmpy does not handle nan
->>> _g.mpf(n)
-Traceback (most recent call last):
-  ...
-ValueError: gmpy does not handle nan
->>> _g.mpf(n)
-Traceback (most recent call last):
-  ...
-ValueError: gmpy does not handle nan
+OverflowError: 'mpz' does not support Infinity
+>>> _g.mpfr(n)
+mpfr('nan')
+>>> _g.mpfr(n)
+mpfr('nan')
+>>> _g.mpfr(n)
+mpfr('nan')
 '''
 
 __test__['user_errors']=\
@@ -82,15 +66,15 @@ r'''
 >>> _g.version(23)
 Traceback (most recent call last):
   ...
-TypeError: version expects 0 arguments
->>> _g.gmp_version(23)
+TypeError: version() takes no arguments (1 given)
+>>> _g.mp_version(23)
 Traceback (most recent call last):
   ...
-TypeError: gmp_version expects 0 arguments
+TypeError: mp_version() takes no arguments (1 given)
 >>> _g.get_cache(23)
 Traceback (most recent call last):
   ...
-TypeError: get_cache expects 0 arguments
+TypeError: get_cache() takes no arguments (1 given)
 >>> _g.set_cache()
 Traceback (most recent call last):
   ...
@@ -106,69 +90,41 @@ ValueError: object size must between 0 and 16384
 >>> _g.set_cache(2000,256)
 Traceback (most recent call last):
   ...
-ValueError: cache must between 0 and 1000
+ValueError: cache size must between 0 and 1000
 >>> _g.set_cache(-23,256)
 Traceback (most recent call last):
   ...
-ValueError: cache must between 0 and 1000
+ValueError: cache size must between 0 and 1000
 >>> _g.set_cache(200,256000)
 Traceback (most recent call last):
   ...
 ValueError: object size must between 0 and 16384
->>> _g.set_debug()
+>>> _g.context().precision = -1
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-TypeError: function takes exactly 1 argument (0 given)
->>> _g.set_debug(2,3)
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: function takes exactly 1 argument (2 given)
->>> _g.set_debug('boh')
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: an integer is required
->>> _g.set_minprec(-1)
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-ValueError: minimum precision must be >= 0
->>> _g.set_fcoform(33)
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-ValueError: number of digits n must be 0<n<=30
->>> _g.set_fcoform([])
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: set_fcoform argument must be int, string, or None
+ValueError: invalid value for precision
 >>> _g.mpz('12'+chr(0)+'34')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: string without NULL characters expected
->>> _g.mpf('12'+chr(0)+'34')
+ValueError: string contains NULL characters
+>>> _g.mpfr('12'+chr(0)+'34')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: string without NULL characters expected
+ValueError: invalid digits
 >>> _g.mpq('12'+chr(0)+'34')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: string without NULL characters expected
->>> _g.mpq('bo',256)
+ValueError: string contains NULL characters
+>>> _g.mpq_from_old_binary(b'bo')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
 ValueError: invalid mpq binary (too short)
->>> _g.mpq('bologna',256)
+>>> _g.mpq_from_old_binary(b'bologna')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
 ValueError: invalid mpq binary (num len)
->>> _g.mpq(b'\001\000\000\000\003\002',256)
+>>> _g.mpq_from_old_binary(b'\001\000\000\000\003\002')
 mpq(3,2)
->>> _g.mpq(b'\002\000\000\000\003\377\002',256)
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-ValueError: invalid mpq binary (num sgn)
->>> _g.mpq(b'\001\000\000\000\003\002\377',256)
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-ValueError: invalid mpq binary (den sgn)
 >>> _g.mpq('ba/bo')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
@@ -184,49 +140,49 @@ ValueError: invalid digits
 >>> _g.mpq('1/0')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ZeroDivisionError: mpq: zero denominator
->>> _g.mpf([])
+ZeroDivisionError: zero denominator in 'mpq'
+>>> _g.mpfr([])
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-TypeError: gmpy.mpf() expects numeric or string argument
->>> _g.mpf('bo',0,256)
+TypeError: mpfr() requires numeric or string argument
+>>> _g.mpfr_from_old_binary(b'bo')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: string too short to be a gmpy.mpf binary encoding
->>> _g.mpf('bo')
+ValueError: invalid mpf binary encoding (too short)
+>>> _g.mpfr('bo')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
 ValueError: invalid digits
 >>> int(_g.mpz(1000*1000*1000*1000*1000*1000*1000))
 1000000000000000000000
->>> _g.scan0(12,-1)
+>>> _g.bit_scan0(12,-1)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
 ValueError: starting bit must be >= 0
->>> _g.scan1(12,-1)
+>>> _g.bit_scan1(12,-1)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
 ValueError: starting bit must be >= 0
->>> _g.lowbits(12,-1)
+>>> _g.f_mod_2exp(12,-1)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: nbits must be > 0
->>> _g.getbit(12,-1)
+OverflowError: can't convert negative value to unsigned int
+>>> _g.bit_test(12,-1)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
 ValueError: bit_index must be >= 0
->>> _g.setbit(12,-1)
+>>> _g.bit_set(12,-1)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
 ValueError: bit_index must be >= 0
->>> _g.mpz(23).setbit(12,1,2,3)
+>>> _g.mpz(23).bit_set(12,1,2,3)
 Traceback (most recent call last):
   ...
-TypeError: setbit() expects 'mpz','int'[,'int'] arguments
->>> _g.setbit(12,1,2,3)
+TypeError: bit_set() takes exactly one argument (4 given)
+>>> _g.bit_set(12,1,2,3)
 Traceback (most recent call last):
   ...
-TypeError: setbit() expects 'mpz','int'[,'int'] arguments
+TypeError: bit_set() requires 'mpz','int' arguments
 >>> _g.root(12,-1)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
@@ -235,35 +191,21 @@ ValueError: n must be > 0
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
 ValueError: n must be > 0
->>> _g.root(-12,2)
+>>> _g.iroot(-12,2)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: root of negative number
+ValueError: iroot() of negative number
 >>> _g.digits(3,'peep')
 Traceback (most recent call last):
   ...
-TypeError: digits() expects 'mpz',['int'] arguments
+TypeError: digits() requires 'int' argument for base
 >>> _g.digits(3.14)
-Traceback (most recent call last):
-  ...
-TypeError: digits() expects 'mpz',['int'] arguments
->>> _g.fdigits(3.14,'peep')
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: an integer is required
->>> _g.qdigits(3.14)
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: argument can not be converted to mpq
->>> _g.qdigits(3,'peep')
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: an integer is required
+('31400000000000001', 1, 53)
 >>> _g.mpz(3).digits('bu')
 Traceback (most recent call last):
   ...
-TypeError: digits() expects 'mpz',['int'] arguments
->>> _g.mpf(3).digits('bu')
+TypeError: digits() requires 'int' argument for base
+>>> _g.mpfr(3).digits('bu')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
 TypeError: an integer is required
@@ -271,7 +213,7 @@ TypeError: an integer is required
 mpz(3)
 >>> _g.qdiv(3,_g.mpz(1))
 mpz(3)
->>> _g.qdiv(3,_g.mpf(1))
+>>> _g.qdiv(3,_g.mpfr(1))
 mpz(3)
 >>> _g.qdiv(3,1.0)
 mpz(3)
@@ -282,11 +224,7 @@ mpz(3)
 >>> _g.qdiv(3,'bu')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-TypeError: second argument can not be converted to mpq
->>> _g.mpq(2).qdiv(3,4)
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: function takes at most 1 argument (2 given)
+TypeError: second argument cannot be converted to 'mpq'
 >>> _g.qdiv(3,4,5)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
@@ -294,172 +232,164 @@ TypeError: function takes at most 2 arguments (3 given)
 >>> _g.qdiv('bu')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-TypeError: first argument can not be converted to mpq
+TypeError: first argument cannot be converted to 'mpq'
 >>> _g.qdiv(1.0,1)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-TypeError: first argument can not be converted to mpq
+TypeError: first argument cannot be converted to 'mpq'
 >>> _g.qdiv(1,0)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ZeroDivisionError: qdiv: zero divisor
+ZeroDivisionError: division or modulo by zero in qdiv
 >>> _g.f2q(-1.0)
 mpz(-1)
 >>> _g.mpz(1,2,3)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-TypeError: gmpy.mpz() requires 1 or 2 arguments
+TypeError: function takes at most 2 arguments (3 given)
 >>> _g.mpz('bi','bo')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-TypeError: gmpy.mpz(): base must be an integer
+TypeError: an integer is required
 >>> _g.mpz('bi',99)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: base for gmpy.mpz must be 0, 256, or in the interval 2 ... 62 .
+ValueError: base for mpz() must be 0 or in the interval 2 ... 62
 >>> _g.mpz(1,2)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-TypeError: gmpy.mpz() with numeric argument needs exactly 1 argument
+TypeError: mpz() with non-string argument needs exactly 1 argument
 >>> _g.mpz(None)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-TypeError: gmpy.mpz() expects numeric or string argument
+TypeError: mpz() requires numeric or string argument
 >>> _g.mpq(1,2,3)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-TypeError: gmpy.mpq() requires 1 or 2 arguments
+TypeError: mpq() requires 0, 1 or 2 arguments
 >>> _g.mpq('bi','bo')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-TypeError: gmpy.mpq(): base must be an integer
+TypeError: an integer is required
 >>> _g.mpq('bi',99)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: base for gmpy.mpq() must be 0, 256, or in the interval 2 ... 36 .
+ValueError: base for mpq() must be 0 or in the interval 2 ... 62
 >>> _g.mpq(None)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-TypeError: gmpy.mpq() expects numeric or string argument
+TypeError: mpq() requires numeric or string argument
 >>> _g.mpq(1,None)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-TypeError: argument can not be converted to mpq
+TypeError: mpq() requires numeric or string argument
 >>> _g.mpq(1,0)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ZeroDivisionError: mpq: zero denominator
->>> _g.mpf()
+ZeroDivisionError: zero denominator in 'mpq'
+>>> _g.mpfr()
+mpfr('0.0')
+>>> _g.mpfr(1,'bo')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-TypeError: gmpy.mpf() requires 1 to 3 arguments
->>> _g.mpf(1,'bo')
+TypeError: an integer is required
+>>> _g.mpfr(1,-1)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-TypeError: gmpy.mpf(): bits must be an integer
->>> _g.mpf(1,-1)
+ValueError: precision for mpfr() must be >= 0
+>>> _g.mpfr('ba',0,'bu')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: bits for gmpy.mpf must be >= 0
->>> _g.mpf('ba',0,'bu')
+TypeError: an integer is required
+>>> _g.mpfr('ba',0,99)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-TypeError: gmpy.mpf(): base must be an integer
->>> _g.mpf('ba',0,99)
+ValueError: base for mpfr() must be 0 or in the interval 2 ... 62
+>>> _g.mpfr(1,2,3)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: base for gmpy.mpf must be 0, 256, or in the interval 2 ... 62 .
->>> _g.mpf(1,2,3)
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: gmpy.mpf() with numeric 1st argument needs 1 or 2 arguments
+TypeError: function takes at most 2 arguments (3 given)
 >>> +_g.mpz(1)
 mpz(1)
->>> +_g.mpf(1)
-mpf('1.e0')
+>>> +_g.mpfr(1)
+mpfr('1.0')
 >>> +_g.mpq(1)
 mpq(1,1)
 >>> _g.mpz(2)**-2
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: mpz.pow with negative power
->>> _g.mpz(2)**_g.mpz(1000000*10000000000000)
+ValueError: pow() exponent cannot be negative
+>>> _g.mpz(2)**_g.mpz(1000000000000000*1000000000000000)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: mpz.pow outrageous exponent
+ValueError: pow() outrageous exponent
 >>> pow(_g.mpz(2),3,0)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: mpz.pow divide by zero
+ValueError: pow() 3rd argument cannot be 0
 >>> pow(_g.mpz(2),3,-5)
 mpz(-2)
 >>> pow(_g.mpq(2),3,-5)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: mpq.pow no modulo allowed
+TypeError: mpq.pow() no modulo allowed
 >>> a=10000000000**2
 >>> _g.mpq(2)**a
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: mpq.pow outrageous exp num
+ValueError: mpq.pow() outrageous exponent
 >>> _g.mpq(2)**_g.mpq(1,a)
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-ValueError: mpq.pow outrageous exp den
+mpfr('1.0')
 >>> _g.mpq(2)**0
 mpq(1,1)
 >>> _g.mpq(2)**-1
 mpq(1,2)
 >>> _g.mpq(2)**_g.mpq(1,2)
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-ValueError: mpq.pow fractional exponent, inexact-root
+mpfr('1.4142135623730951')
 >>> _g.mpq(-2)**_g.mpq(1,2)
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-ValueError: mpq.pow fractional exponent, nonreal-root
+mpfr('nan')
 >>> _g.mpq(0)**_g.mpq(1,2)
-mpq(0,1)
+mpfr('0.0')
 >>> _g.mpq(0)**-1
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ZeroDivisionError: mpq.pow 0 base to <0 exponent
+ZeroDivisionError: mpq.pow() 0 base to negative exponent
 >>> _g.mpq(-1)**-1
 mpq(-1,1)
->>> _g.mpf(9,100)**2
-mpf('8.1e1',100)
->>> _g.mpf(9,100)**0.5
-mpf('3.e0',100)
->>> _g.mpf(9,100)**_g.mpf(0.5)
-mpf('3.e0')
->>> _g.mpf(0)**2
-mpf('0.e0')
->>> pow(_g.mpf(2),3,-5)
+>>> _g.mpfr(9,100)**2
+mpfr('81.0')
+>>> _g.mpfr(9,100)**0.5
+mpfr('3.0')
+>>> _g.mpfr(9,100)**_g.mpfr(0.5)
+mpfr('3.0')
+>>> _g.mpfr(0)**2
+mpfr('0.0')
+>>> pow(_g.mpfr(2),3,-5)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: mpf.pow no modulo allowed
+TypeError: pow() 3rd argument not allowed unless all arguments are integers
 >>> _g.mpz(1)+'bu'
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
 TypeError: unsupported operand type(s) for +: 'mpz' and 'str'
->>> _g.mpz(1)+_g.mpf(1)
-mpf('2.e0')
+>>> _g.mpz(1)+_g.mpfr(1)
+mpfr('2.0')
 >>> _g.mpz(1)+_g.mpq(1)
 mpq(2,1)
 >>> _g.mpq(1)+'bu'
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
 TypeError: unsupported operand type(s) for +: 'mpq' and 'str'
->>> _g.mpf(1)+'bu'
+>>> _g.mpfr(1)+'bu'
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-TypeError: unsupported operand type(s) for +: 'mpf' and 'str'
->>> _g.mpf(1)+_g.mpq(2)
-mpf('3.e0')
+TypeError: unsupported operand type(s) for +: 'mpfr' and 'str'
+>>> _g.mpfr(1)+_g.mpq(2)
+mpfr('3.0')
 >>> divmod(_g.mpz(3),0)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ZeroDivisionError: mpz divmod by zero
+ZeroDivisionError: division or modulo by zero
 >>> divmod(_g.mpz(0),3)
 (mpz(0), mpz(0))
 >>> _g.divm(1,2,0)
@@ -475,7 +405,7 @@ mpq(1,1)
 >>> _g.fac(-1)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: factorial of negative number
+ValueError: fac() of negative number
 >>> _g.fib(-1)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
@@ -484,26 +414,22 @@ ValueError: Fibonacci of negative number
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
 ValueError: binomial coefficient with negative k
->>> _g.sqrt(-1)
+>>> _g.isqrt_rem(-1)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: sqrt of negative number
->>> _g.sqrtrem(-1)
+ValueError: isqrt_rem() of negative number
+>>> _g.isqrt(-1)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
-ValueError: sqrt of negative number
->>> _g.fsqrt(-1)
-Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-ValueError: sqrt of negative number
+ValueError: isqrt() of negative number
 >>> _g.jacobi(23, -34)
 Traceback (most recent call last):
   ...
-ValueError: jacobi's y must be odd prime > 0
+ValueError: y must be odd and >0
 >>> _g.legendre(23, -34)
 Traceback (most recent call last):
   ...
-ValueError: legendre's y must be odd and > 0
+ValueError: y must be odd and >0
 >>> # guard against conversion error on 64-bit systems
 >>> _g.mpz(2**32) != _g.mpz(0)
 True
@@ -516,21 +442,18 @@ True
 
 def _test(chat=None):
     if chat:
-        print("Unit tests for gmpy 1.15 (extra cover)")
-        print("    running on Python", sys.version)
-        print()
-        if _g.gmp_version():
-            print("Testing gmpy %s (GMP %s), default caching (%s, %s)" % (
-                (_g.version(), _g.gmp_version(), _g.get_cache()[0],
-                _g.get_cache()[1])))
-        else:
-            print("Testing gmpy %s (MPIR %s), default caching (%s, %s)" % (
-                (_g.version(), _g.mpir_version(), _g.get_cache()[0],
-                _g.get_cache()[1])))
+        print("Unit tests for gmpy2 (extra cover)")
+        print("    on Python %s" % sys.version)
+        print("Testing gmpy2 {0}".format(_g.version()))
+        print("  Mutliple-precision library:   {0}".format(_g.mp_version()))
+        print("  Floating-point library:       {0}".format(_g.mpfr_version()))
+        print("  Complex library:              {0}".format(_g.mpc_version()))
+        print("  Caching Values: (Number)      {0}".format(_g.get_cache()[0]))
+        print("  Caching Values: (Size, limbs) {0}".format(_g.get_cache()[1]))
 
         print(__test__.keys())
     thismod = sys.modules.get(__name__)
-    doctest.testmod(thismod, report=0)
+    doctest.testmod(thismod, report=0, optionflags=doctest.IGNORE_EXCEPTION_DETAIL)
 
     if chat:
         print()
